# Руководство по использованию

*[English](../en/usage.md) | [中文](../zh/usage.md) | [Français](../fr/usage.md) | [Español](../es/usage.md) | [العربية](../ar/usage.md) | Русский*

Этот документ предоставляет подробные инструкции по использованию MCP Database Utilities, помогая вам максимально использовать его возможности для анализа данных с помощью ИИ.

## Основной рабочий процесс

Основной рабочий процесс использования MCP Database Utilities выглядит следующим образом:

1. **Настройка подключений к базе данных**: Определите ваши подключения к базе данных в файле `config.yaml`
2. **Запуск службы MCP**: Запустите службу через конфигурацию вашего ИИ-клиента
3. **Взаимодействие с ИИ**: Задавайте вопросы о ваших базах данных на естественном языке
4. **Просмотр результатов**: ИИ выполнит необходимые запросы и представит результаты в легко понятном формате

## Доступные инструменты

MCP Database Utilities предоставляет несколько инструментов, которые может использовать ваш ИИ:

### dbutils-list-connections

Перечисляет все доступные подключения к базам данных, определенные в вашей конфигурации.

**Пример взаимодействия**:

**Вы**: "Какие подключения к базам данных у меня доступны?"

**ИИ**: "Я проверю ваши доступные подключения к базам данных. Вот что я нашел:

1. **postgres-db**
   - Тип: PostgreSQL
   - Хост: localhost
   - База данных: analytics
   - Пользователь: analyst

2. **sqlite-db**
   - Тип: SQLite
   - Путь: /path/to/database.db

3. **mysql-db**
   - Тип: MySQL
   - Хост: db.example.com
   - База данных: customer_data
   - Пользователь: reader"

### dbutils-list-tables

Перечисляет все таблицы в указанной базе данных.

**Пример взаимодействия**:

**Вы**: "Перечислите все таблицы в моей базе данных postgres."

**ИИ**: "Я проверю это для вас. Вот таблицы в вашей базе данных postgres:
- клиенты
- продукты
- заказы
- инвентарь
- сотрудники"

### dbutils-run-query

Выполняет SQL-запросы к указанной базе данных (только операции SELECT).

**Пример взаимодействия**:

**Вы**: "Запросите количество клиентов, которые зарегистрировались за последние 30 дней."

**ИИ**: "Я проверю это для вас. Согласно данным, за последние 30 дней было 42 новых регистрации клиентов."

### dbutils-get-stats

Получает статистику по таблице, такую как количество строк, размер и статистика по столбцам.

**Пример взаимодействия**:

**Вы**: "Получите статистику для таблицы продуктов."

**ИИ**: "Вот статистика для таблицы продуктов:
- Всего строк: 1,245
- Размер таблицы: 2.3 МБ
- Статистика по столбцам:
  * product_id: 1,245 уникальных значений
  * категория: 8 различных категорий
  * цена: среднее $45.99, мин $5.99, макс $299.99"

### dbutils-list-constraints

Перечисляет ограничения для таблицы, такие как первичные ключи, внешние ключи и т.д.

**Пример взаимодействия**:

**Вы**: "Покажите ограничения для таблицы заказов."

**ИИ**: "Таблица заказов имеет следующие ограничения:
- Первичный ключ: order_id
- Внешний ключ: customer_id ссылается на клиенты(id)
- Внешний ключ: product_id ссылается на продукты(id)
- Ограничение проверки: order_amount > 0"

### dbutils-explain-query

Получает план выполнения запроса и оценки стоимости.

**Пример взаимодействия**:

**Вы**: "Объясните план выполнения для этого запроса: SELECT * FROM orders WHERE customer_id = 123"

**ИИ**: "План выполнения для этого запроса:
1. Сканирование индекса: использование индекса customer_id_idx
2. Оценочная стоимость: 12.5
3. Оценочное количество строк: 8
4. Условие фильтрации: customer_id = 123"

### dbutils-get-performance

Получает метрики производительности базы данных.

**Пример взаимодействия**:

**Вы**: "Получите метрики производительности для базы данных."

**ИИ**: "Текущие метрики производительности базы данных:
- Время выполнения запроса: в среднем 45 мс
- Коэффициент попаданий в кэш: 87%
- Активные соединения: 3
- Недавний коэффициент ошибок: 0.2%"

### dbutils-analyze-query

Анализирует производительность SQL-запросов и предоставляет предложения по оптимизации.

**Пример взаимодействия**:

**Вы**: "Проанализируйте этот запрос: SELECT * FROM orders JOIN customers ON orders.customer_id = customers.id WHERE order_date > '2023-01-01'"

**ИИ**: "Результаты анализа запроса:
1. Проблема производительности: Использование SELECT * извлекает ненужные столбцы
2. Отсутствующий индекс: Нет индекса на столбце order_date
3. Предложения по оптимизации:
   - Выбирайте только необходимые столбцы
   - Добавьте индекс на столбец order_date
   - Рассмотрите возможность добавления предложения LIMIT для ограничения количества результатов"

## Распространенные сценарии использования

### 1. Исследование данных

**Вы**: "Я хочу понять структуру моей базы данных."

**ИИ**: "Я могу помочь вам исследовать структуру вашей базы данных. Позвольте мне перечислить все таблицы, а затем вы можете выбрать одну, чтобы узнать больше о ее структуре."

**Вы**: "Хорошо, перечислите все таблицы."

**ИИ**: "Ваша база данных содержит следующие таблицы:
- клиенты
- продукты
- заказы
- инвентарь
- сотрудники

О какой таблице вы хотели бы узнать больше?"

**Вы**: "Расскажите мне о структуре таблицы клиентов."

**ИИ**: "Таблица клиентов имеет следующую структуру:
- id (целое число, первичный ключ)
- имя (varchar(100), не null)
- email (varchar(100), уникальный, не null)
- дата_регистрации (дата, не null)
- последний_вход (timestamp)
- статус (enum: 'активный', 'неактивный', 'приостановлен')"

### 2. Анализ данных

**Вы**: "Проанализируйте тенденции продаж за последние 6 месяцев."

**ИИ**: "Я проанализирую тенденции продаж за последние 6 месяцев. Позвольте мне выполнить несколько запросов..."

[ИИ выполняет несколько запросов, анализируя данные о продажах]

**ИИ**: "На основе анализа последних 6 месяцев:
1. Общие продажи: $1,245,678, рост на 15% по сравнению с предыдущими 6 месяцами
2. Самый продаваемый продукт: Продукт X, составляющий 23% от общих продаж
3. Пиковые периоды продаж: пятницы и субботы, составляющие 45% от общих продаж
4. Коэффициент удержания клиентов: 78%, рост на 5% по сравнению с предыдущими 6 месяцами"

### 3. Анализ между базами данных

**Вы**: "Сравните структуру таблицы пользователей между производственной и тестовой базами данных."

**ИИ**: "Я сравню структуру таблицы пользователей между двумя базами данных..."

[ИИ запрашивает обе базы данных для структур таблиц]

**ИИ**: "Различия в структуре таблицы пользователей между производственной и тестовой базами данных:
1. Производственная имеет дополнительный столбец 'last_login_ip' (varchar(45))
2. Столбец 'email' в тестовой базе данных не имеет уникального ограничения
3. Производственная имеет дополнительный индекс: idx_user_status
4. Тестовая база данных не имеет ограничения внешнего ключа: fk_user_role"

## Лучшие практики

### Оптимизация запросов

1. **Ограничение размера результирующего набора**: Используйте предложения LIMIT для ограничения количества возвращаемых строк
2. **Выбор только необходимых столбцов**: Избегайте использования SELECT *
3. **Использование индексированных столбцов**: Используйте столбцы с индексами в предложениях WHERE
4. **Избегание сложных вычислений**: Перенесите сложные вычисления на уровень приложения

### Рекомендации по безопасности

1. **Использование учетных записей только для чтения**: Создавайте выделенные учетные записи базы данных только для чтения для доступа ИИ
2. **Ограничение доступа к таблицам**: Предоставляйте доступ только к необходимым таблицам
3. **Использование SSL/TLS**: Включите шифрование для удаленных подключений к базе данных
4. **Регулярная смена паролей**: Периодически меняйте пароли базы данных

### Оптимизация производительности

1. **Настройка пула соединений**: Настройте размер пула соединений в зависимости от вашего использования
2. **Настройки тайм-аута запроса**: Установите разумные длительности тайм-аута для запросов
3. **Кэширование результатов**: Рассмотрите возможность кэширования для часто запрашиваемых данных
4. **Мониторинг производительности**: Регулярно проверяйте метрики производительности для выявления потенциальных проблем

## Устранение неполадок

Если вы столкнулись с проблемами во время использования, обратитесь к разделу устранения неполадок в [Руководстве по установке](installation.md) или обратитесь к [Технической документации](technical/architecture.md) для получения более подробной информации.
